"""Список русских стоп-слов."""

stop_words = [
    "а",
    "абсолютно",
    "аж",
    "более",
    "больше",
    "бы",
    "быстро",
    "в",
    "во",
    "ведь",
    "весь",
    "вместе",
    "вновь",
    "вовсе",
    "вообще",
    "вот",
    "впервые",
    "вполне",
    "впрочем",
    "временами",
    "временный",
    "всегда",
    "всего",
    "все-таки",
    "вчистую",
    "даже",
    "данный",
    "для",
    "до",
    "довольно",
    "довольно-таки",
    "долго",
    "долгий",
    "еще",
    "ж",
    "же",
    "за",
    "затем",
    "зато",
    "здесь",
    "и",
    "ибо",
    "или",
    "именно",
    "иногда",
    "к",
    "как-то",
    "какой-то",
    "классный",
    "конечно",
    "красивый",
    "кряду",
    "ли",
    "мало",
    "менее",
    "много",
    "мой",
    "на",
    "наверно",
    "наверное",
    "наш",
    "немало",
    "немного",
    "неплохой",
    "несколько",
    "никак",
    "никогда",
    "но",
    "ну",
    "ну-ка",
    "о",
    "об",
    "однако",
    "ой",
    "опять",
    "особо",
    "особенно",
    "от",
    "ох",
    "очень",
    "очередной",
    "перед",
    "плохой",
    "по",
    "под",
    "подробно",
    "подробный",
    "подряд",
    "поздний",
    "пока",
    "полностью",
    "постоянно",
    "потом",
    "почти",
    "при",
    "просто",
    "прямиком",
    "прямой",
    "пусть",
    "раз",
    "рано",
    "сам",
    "самый",
    "свой",
    "себя",
    "сей",
    "сейчас",
    "слишком",
    "снова",
    "совсем",
    "сразу",
    "стать",
    "так",
    "также",
    "такой",
    "там",
    "теперь",
    "то",
    "тогда",
    "тоже",
    "только",
    "тот",
    "тут",
    "уверенно",
    "увы",
    "уж",
    "уже",
    "ура",
    "хорошо",
    "хотя",
    "часто",
    "чуть",
    "это",
    "этот",
]
